/***********************************************************************************************************************************
BZ2 Decompress

Decompress IO from the bz2 format.
***********************************************************************************************************************************/
#ifndef COMMON_COMPRESS_BZ2_DECOMPRESS_H
#define COMMON_COMPRESS_BZ2_DECOMPRESS_H

#include "common/io/filter/filter.h"

/***********************************************************************************************************************************
Filter type constant
***********************************************************************************************************************************/
#define BZ2_DECOMPRESS_FILTER_TYPE                                   STRID5("bz2-dcmp", 0x83464df3420)

/***********************************************************************************************************************************
Constructors
***********************************************************************************************************************************/
FN_EXTERN IoFilter *bz2DecompressNew(void);

#endif
